#!perl -T

use strict;
use warnings;

use Test::More;
eval "use Test::Pod::Coverage 1.04"; ## no critic(ProhibitStringyEval)
plan skip_all => "Test::Pod::Coverage 1.04 required for testing POD coverage" if $@;
all_pod_coverage_ok();
